@@ -1,15 +1,14 @@
+import djangomaster
+
 from django.conf import settings
 from django.conf.urls import patterns, url, include
 from django.conf.urls.static import static
 
 
-import djangomaster
-
-
 urlpatterns = patterns(
     r'',
 
-    url(r'^master', include(djangomaster.urls)),
+    url(r'^master/', include(djangomaster.urls)),
 
 )
 
